/*GPL*START*
 * qload - graphical frontend to ruptime
 * 
 * Copyright (C) 1998 by Johannes Overmann <overmann@iname.com>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 * *GPL*END*/  

#include <qapp.h>
#include <qpushbt.h>
#include <qlayout.h>
#include <qlabel.h>

#include "mainwidget.h"
#include "tappconfig.h"


const char *options[] ={
   "#usage='Usage: %n [OPTIONS]\n'",
   "#trailer='\nX toolkit options (like -display, -geometry, -fg, -font ...) are also available\n\n%n version %v *** (C) 1997-1999 by Johannes Overmann\ncomments, bugs and suggestions welcome: %e\n%gpl'",
   "name=verbose, type=switch, char=v, help=verbose execution, headline='common options:'",
   "name=ruptime, type=string, save, default=ruptime, help=use this command to get the ruptime info",
   "name=memory-file, type=string, save, default=ram.txt, help=file searched for info about the available ram on the machines",
   "name=groups-file, type=string, save, default=group.txt, help=file containing the group splitting of the machines",
   "name=popup-file, type=string, save, default=popup.txt, help=file containing the popup commands",
   "name=arch-file, type=string, save, default=arch.txt, help=file containing the architectures of all machines",
   "name=auto-save, type=bool, save, help=auto save config at exit",
   "name=update, type=int, lower=1, default=36, save, help=update frequency in seconds, param=SEC",
   "name=graph-grid, type=bool, default=true, save, help=draw grid in graph mode",
   "name=graph-mode, type=int, lower=0, upper=2, save, help='draw one graph for 0=each machine, 1=each group, 2=all'",
   "name=graph-reverse, type=bool, default=false, save, help=reverse colors in graph mode",
   "name=graph-history, type=int, save, default=4800, lower=5, help=history lenght in graph mode, param=LEN",
   "name=graph-hosts, type=string, save, help=comma separated list of host to diplay in graph mode",
   "name=startup, type=int, save, lower=0, upper=3, help='startup: 0=about, 1=load, 2=graph, 3=groups'",
   "name=sort, type=int, save, lower=0, upper=11, help='sort: 0=name, 1=group, 2=ram, 3=load1, 4=load5, 5=load15, 6-11=reverse of 0-5'",
   "EOL"
};


int main(int ac, char *av[]) {
   QApplication::setFont(QFont("helvetica", 12, QFont::Bold));
   QApplication qa(ac, av);
   TAppConfig ta(options, "options", ac, av, "QLOAD_OPT", "qloadrc", VERSION);
   QWidget w;

   QBoxLayout lay0(&w,QBoxLayout::Down, 5);
   QFrame fra(&w);
   MainWidget mainwid(&fra);
   QBoxLayout layfra(&fra, QBoxLayout::Down,1);
   layfra.addWidget(&mainwid);
   fra.setLineWidth(1);
   fra.setFrameStyle(QFrame::Panel|QFrame::Sunken);
   lay0.addWidget(&fra, 1);
   QBoxLayout lay1(QBoxLayout::LeftToRight, 5);
   lay0.addLayout(&lay1,0);
   
   QPushButton load("Load", &w), groups("Groups", &w), quit("Quit", &w), about("About", &w), graph("Graph", &w), setup("Setup", &w);

   lay1.addWidget(&load, 10);
   lay1.addWidget(&groups, 10);
   lay1.addWidget(&graph, 10);
   lay1.addStretch(5);
   lay1.addWidget(&about, 10);
   lay1.addStretch(5);
   lay1.addWidget(&setup, 10);
   lay1.addStretch(5);
   lay1.addWidget(&quit, 10);
   lay1.addStrut(load.sizeHint().height());
   
	//   QObject::connect(&quit, SIGNAL(clicked()), qApp, SLOT(quit())); 
   QObject::connect(&quit, SIGNAL(clicked()), &mainwid, SLOT(want_quit())); 
   QObject::connect(&load, SIGNAL(clicked()), &mainwid, SLOT(disp_load())); 
   QObject::connect(&groups, SIGNAL(clicked()), &mainwid, SLOT(disp_groups())); 
   QObject::connect(&graph, SIGNAL(clicked()), &mainwid, SLOT(disp_graph())); 
   QObject::connect(&setup, SIGNAL(clicked()), &mainwid, SLOT(toggle_setup()));
   QObject::connect(&about, SIGNAL(clicked()), &mainwid, SLOT(disp_about()));
   
   qa.setMainWidget(&w);
   TString capt(ta.getString("application-name")+" V"+ta.getString("application-version"));
   w.setCaption(capt);
   w.setMinimumSize(400,200);
   w.show();
   return qa.exec();
}










